<img width="960" alt="Screenshot 2025-06-19 at 20 42 59" src="https://github.com/user-attachments/assets/afbedb6a-a0d2-44a0-99e3-cd827990202c" />

Input any .tif DEM and get an interactive 3d visualization, rendered in ASCII!
Colors are currently based on depth. A DEM of the San Francisco Bay Area has been included in `./data` as a demo.

# Installation
Run `pip install earthscii`

# Usage
Run `earthscii -h` for help.
Arrow keys to pan, `w`/`s` for **x** rotation, `,`/`.` for **y** rotation, `a`/`d` for **z** rotation, `=`/`-` for zoom. `r` resets viewing angle. `q` to quit.


Inspired by [mapscii](https://github.com/rastapasta/mapscii).
